Caching Modules (``taurex.cache``)
==================================

Singleton
-----------------------------

.. automodule:: taurex.cache.singleton
   :members:
   :undoc-members:
   :show-inheritance:

OpacityCache
--------------------------------

.. automodule:: taurex.cache.opacitycache
   :members:
   :undoc-members:
   :show-inheritance:


CIACache
-----------------------------

.. automodule:: taurex.cache.ciaacache
   :members:
   :undoc-members:
   :show-inheritance:
